==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CustomerManagementService/CurrencyType.pm <==
package Microsoft::AdCenter::V7::CustomerManagementService::CurrencyType;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

sub AlgerianDinar {
    return 'AlgerianDinar';
}

sub ArgentinePeso {
    return 'ArgentinePeso';
}

sub ArmenianDram {
    return 'ArmenianDram';
}

sub AustralianDollar {
    return 'AustralianDollar';
}

sub AzerbaijanianManat {
    return 'AzerbaijanianManat';
}

sub BahrainiDinar {
    return 'BahrainiDinar';
}

sub Baht {
    return 'Baht';
}

sub Balboa {
    return 'Balboa';
}

sub BelarussianRuble {
    return 'BelarussianRuble';
}

sub BelizeDollar {
    return 'BelizeDollar';
}

sub Bolivar {
    return 'Bolivar';
}

sub Boliviano {
    return 'Boliviano';
}

sub BrazilianReal {
    return 'BrazilianReal';
}

sub BruneiDollar {
    return 'BruneiDollar';
}

sub CanadianDollar {
    return 'CanadianDollar';
}

sub ChileanPeso {
    return 'ChileanPeso';
}

sub ColombianPeso {
    return 'ColombianPeso';
}

sub CordobaOro {
    return 'CordobaOro';
}

sub CostaRicanColon {
    return 'CostaRicanColon';
}

sub Croatiankuna {
    return 'Croatiankuna';
}

sub CzechKoruna {
    return 'CzechKoruna';
}

sub DanishKrone {
    return 'DanishKrone';
}

sub Denar {
    return 'Denar';
}

sub DominicanPeso {
    return 'DominicanPeso';
}

sub Dong {
    return 'Dong';
}

sub EgyptianPound {
    return 'EgyptianPound';
}

sub Euro {
    return 'Euro';
}

sub Forint {
    return 'Forint';
}

sub Guarani {
    return 'Guarani';
}

sub HongKongDollar {
    return 'HongKongDollar';
}

sub Hryvnia {
    return 'Hryvnia';
}

sub IcelandKrona {
    return 'IcelandKrona';
}

sub IndianRupee {
    return 'IndianRupee';
}

sub IranianRial {
    return 'IranianRial';
}

sub IraqiDinar {
    return 'IraqiDinar';
}

sub JamaicanDollar {
    return 'JamaicanDollar';
}

sub JapaneseYen {
    return 'JapaneseYen';
}

sub JordanianDinar {
    return 'JordanianDinar';
}

sub KenyanShilling {
    return 'KenyanShilling';
}

sub Kroon {
    return 'Kroon';
}

sub KuwaitiDinar {
    return 'KuwaitiDinar';
}

sub Lari {
    return 'Lari';
}

sub LatvianLats {
    return 'LatvianLats';
}

sub LebanesePound {
    return 'LebanesePound';
}

sub Lek {
    return 'Lek';
}

sub Lempira {
    return 'Lempira';
}

sub Leu {
    return 'Leu';
}

sub Lev {
    return 'Lev';
}

sub LibyanDinar {
    return 'LibyanDinar';
}

sub LithuanianLitus {
    return 'LithuanianLitus';
}

sub MalaysianRinggit {
    return 'MalaysianRinggit';
}

sub MexicanPeso {
    return 'MexicanPeso';
}

sub MoroccanDirham {
    return 'MoroccanDirham';
}

sub NewIsraeliSheqel {
    return 'NewIsraeliSheqel';
}

sub NewTaiwanDollar {
    return 'NewTaiwanDollar';
}

sub NewZealandDollar {
    return 'NewZealandDollar';
}

sub NorwegianKrone {
    return 'NorwegianKrone';
}

sub NuevoSol {
    return 'NuevoSol';
}

sub PakistanRupee {
    return 'PakistanRupee';
}

sub Pataca {
    return 'Pataca';
}

sub PesoUruguayo {
    return 'PesoUruguayo';
}

sub PhilippinePeso {
    return 'PhilippinePeso';
}

sub QatariRial {
    return 'QatariRial';
}

sub Quetzal {
    return 'Quetzal';
}

sub RialOmani {
    return 'RialOmani';
}

sub Rufiyaa {
    return 'Rufiyaa';
}

sub Rupiah {
    return 'Rupiah';
}

sub RussianRuble {
    return 'RussianRuble';
}

sub SaudiRiyal {
    return 'SaudiRiyal';
}

sub SingaporeDollar {
    return 'SingaporeDollar';
}

sub SlovakKoruna {
    return 'SlovakKoruna';
}

sub Som {
    return 'Som';
}

sub SouthAfricanRand {
    return 'SouthAfricanRand';
}

sub SwedishKrona {
    return 'SwedishKrona';
}

sub SwissFranc {
    return 'SwissFranc';
}

sub SyrianPound {
    return 'SyrianPound';
}

sub Tenge {
    return 'Tenge';
}

sub Tolar {
    return 'Tolar';
}

sub TrinidadandTobagoDollar {
    return 'TrinidadandTobagoDollar';
}

sub Tugrik {
    return 'Tugrik';
}

sub TunisianDinar {
    return 'TunisianDinar';
}

sub TurkishLira {
    return 'TurkishLira';
}

sub UAEDirham {
    return 'UAEDirham';
}

sub UKPound {
    return 'UKPound';
}

sub USDollar {
    return 'USDollar';
}

sub UzbekistanSum {
    return 'UzbekistanSum';
}

sub Won {
    return 'Won';
}

sub YemeniRial {
    return 'YemeniRial';
}

sub YuanRenminbi {
    return 'YuanRenminbi';
}

sub YugoslavianNewDinar {
    return 'YugoslavianNewDinar';
}

sub ZimbabweDollar {
    return 'ZimbabweDollar';
}

sub Zloty {
    return 'Zloty';
}

1;

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V7/CustomerManagementService/CurrencyType.pm <==
package Microsoft::AdCenter::V7::CustomerManagementService::CurrencyType;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::CustomerManagementService::CurrencyType - Represents "CurrencyType" in Microsoft AdCenter Customer Management Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

AlgerianDinar
ArgentinePeso
ArmenianDram
AustralianDollar
AzerbaijanianManat
BahrainiDinar
Baht
Balboa
BelarussianRuble
BelizeDollar
Bolivar
Boliviano
BrazilianReal
BruneiDollar
CanadianDollar
ChileanPeso
ColombianPeso
CordobaOro
CostaRicanColon
Croatiankuna
CzechKoruna
DanishKrone
Denar
DominicanPeso
Dong
EgyptianPound
Euro
Forint
Guarani
HongKongDollar
Hryvnia
IcelandKrona
IndianRupee
IranianRial
IraqiDinar
JamaicanDollar
JapaneseYen
JordanianDinar
KenyanShilling
Kroon
KuwaitiDinar
Lari
LatvianLats
LebanesePound
Lek
Lempira
Leu
Lev
LibyanDinar
LithuanianLitus
MalaysianRinggit
MexicanPeso
MoroccanDirham
NewIsraeliSheqel
NewTaiwanDollar
NewZealandDollar
NorwegianKrone
NuevoSol
PakistanRupee
Pataca
PesoUruguayo
PhilippinePeso
QatariRial
Quetzal
RialOmani
Rufiyaa
Rupiah
RussianRuble
SaudiRiyal
SingaporeDollar
SlovakKoruna
Som
SouthAfricanRand
SwedishKrona
SwissFranc
SyrianPound
Tenge
Tolar
TrinidadandTobagoDollar
Tugrik
TunisianDinar
TurkishLira
UAEDirham
UKPound
USDollar
UzbekistanSum
Won
YemeniRial
YuanRenminbi
YugoslavianNewDinar
ZimbabweDollar
Zloty

=cut

sub AlgerianDinar {
    return 'AlgerianDinar';
}

sub ArgentinePeso {
    return 'ArgentinePeso';
}

sub ArmenianDram {
    return 'ArmenianDram';
}

sub AustralianDollar {
    return 'AustralianDollar';
}

sub AzerbaijanianManat {
    return 'AzerbaijanianManat';
}

sub BahrainiDinar {
    return 'BahrainiDinar';
}

sub Baht {
    return 'Baht';
}

sub Balboa {
    return 'Balboa';
}

sub BelarussianRuble {
    return 'BelarussianRuble';
}

sub BelizeDollar {
    return 'BelizeDollar';
}

sub Bolivar {
    return 'Bolivar';
}

sub Boliviano {
    return 'Boliviano';
}

sub BrazilianReal {
    return 'BrazilianReal';
}

sub BruneiDollar {
    return 'BruneiDollar';
}

sub CanadianDollar {
    return 'CanadianDollar';
}

sub ChileanPeso {
    return 'ChileanPeso';
}

sub ColombianPeso {
    return 'ColombianPeso';
}

sub CordobaOro {
    return 'CordobaOro';
}

sub CostaRicanColon {
    return 'CostaRicanColon';
}

sub Croatiankuna {
    return 'Croatiankuna';
}

sub CzechKoruna {
    return 'CzechKoruna';
}

sub DanishKrone {
    return 'DanishKrone';
}

sub Denar {
    return 'Denar';
}

sub DominicanPeso {
    return 'DominicanPeso';
}

sub Dong {
    return 'Dong';
}

sub EgyptianPound {
    return 'EgyptianPound';
}

sub Euro {
    return 'Euro';
}

sub Forint {
    return 'Forint';
}

sub Guarani {
    return 'Guarani';
}

sub HongKongDollar {
    return 'HongKongDollar';
}

sub Hryvnia {
    return 'Hryvnia';
}

sub IcelandKrona {
    return 'IcelandKrona';
}

sub IndianRupee {
    return 'IndianRupee';
}

sub IranianRial {
    return 'IranianRial';
}

sub IraqiDinar {
    return 'IraqiDinar';
}

sub JamaicanDollar {
    return 'JamaicanDollar';
}

sub JapaneseYen {
    return 'JapaneseYen';
}

sub JordanianDinar {
    return 'JordanianDinar';
}

sub KenyanShilling {
    return 'KenyanShilling';
}

sub Kroon {
    return 'Kroon';
}

sub KuwaitiDinar {
    return 'KuwaitiDinar';
}

sub Lari {
    return 'Lari';
}

sub LatvianLats {
    return 'LatvianLats';
}

sub LebanesePound {
    return 'LebanesePound';
}

sub Lek {
    return 'Lek';
}

sub Lempira {
    return 'Lempira';
}

sub Leu {
    return 'Leu';
}

sub Lev {
    return 'Lev';
}

sub LibyanDinar {
    return 'LibyanDinar';
}

sub LithuanianLitus {
    return 'LithuanianLitus';
}

sub MalaysianRinggit {
    return 'MalaysianRinggit';
}

sub MexicanPeso {
    return 'MexicanPeso';
}

sub MoroccanDirham {
    return 'MoroccanDirham';
}

sub NewIsraeliSheqel {
    return 'NewIsraeliSheqel';
}

sub NewTaiwanDollar {
    return 'NewTaiwanDollar';
}

sub NewZealandDollar {
    return 'NewZealandDollar';
}

sub NorwegianKrone {
    return 'NorwegianKrone';
}

sub NuevoSol {
    return 'NuevoSol';
}

sub PakistanRupee {
    return 'PakistanRupee';
}

sub Pataca {
    return 'Pataca';
}

sub PesoUruguayo {
    return 'PesoUruguayo';
}

sub PhilippinePeso {
    return 'PhilippinePeso';
}

sub QatariRial {
    return 'QatariRial';
}

sub Quetzal {
    return 'Quetzal';
}

sub RialOmani {
    return 'RialOmani';
}

sub Rufiyaa {
    return 'Rufiyaa';
}

sub Rupiah {
    return 'Rupiah';
}

sub RussianRuble {
    return 'RussianRuble';
}

sub SaudiRiyal {
    return 'SaudiRiyal';
}

sub SingaporeDollar {
    return 'SingaporeDollar';
}

sub SlovakKoruna {
    return 'SlovakKoruna';
}

sub Som {
    return 'Som';
}

sub SouthAfricanRand {
    return 'SouthAfricanRand';
}

sub SwedishKrona {
    return 'SwedishKrona';
}

sub SwissFranc {
    return 'SwissFranc';
}

sub SyrianPound {
    return 'SyrianPound';
}

sub Tenge {
    return 'Tenge';
}

sub Tolar {
    return 'Tolar';
}

sub TrinidadandTobagoDollar {
    return 'TrinidadandTobagoDollar';
}

sub Tugrik {
    return 'Tugrik';
}

sub TunisianDinar {
    return 'TunisianDinar';
}

sub TurkishLira {
    return 'TurkishLira';
}

sub UAEDirham {
    return 'UAEDirham';
}

sub UKPound {
    return 'UKPound';
}

sub USDollar {
    return 'USDollar';
}

sub UzbekistanSum {
    return 'UzbekistanSum';
}

sub Won {
    return 'Won';
}

sub YemeniRial {
    return 'YemeniRial';
}

sub YuanRenminbi {
    return 'YuanRenminbi';
}

sub YugoslavianNewDinar {
    return 'YugoslavianNewDinar';
}

sub ZimbabweDollar {
    return 'ZimbabweDollar';
}

sub Zloty {
    return 'Zloty';
}

1;
